# config_map

Source: [config_map/core/v1/config_map.k](https://url/to/source_code/config_map/core/v1/config_map.k)

## Schema ConfigMap

### Base Schema
[@config_map.core.metadata.Metadata](../doc_metadata_en#schema-metadata)

### Attributes

|Name and Description|Type|Default Value|Required|
|--------------------|----|-------------|--------|
|**data**|{str: str}|Undefined|optional|
|**binaryData**|{str: str}|Undefined|optional|
<!-- Auto generated by kcl-doc tool, please do not edit. -->
